<?xml version="1.0"?>
<app>

<category>
Children
</category>

<name>
Preschool
</name>

<description>
   <am>Pre-School. Includes: gamine, gcompris and tuxpaint</am>
   <ar>Pre-School. Includes: gamine, gcompris and tuxpaint</ar>
   <bg>Pre-School. Includes: gamine, gcompris and tuxpaint</bg>
   <ca>Pre-escolar: inclou gamine, gcompris i tuxpaint</ca>
   <cs>Pre-School. Includes: gamine, gcompris and tuxpaint</cs>
   <da>Førskole. Inkluderer: gamine, gcompris og tuxpaint</da>
   <de>Vorschule: Inklusive Gamine, Gcompris und Tuxpaint</de>
   <el>Προσχολικός. Περιλαμβάνει: gamine, gcompris και tuxpaint</el>
   <en>Pre-School. Includes: gamine, gcompris and tuxpaint</en>
   <es>Preescolar. Incluye: gamine, gcompris y tuxpaint.</es>
   <et>Pre-School. Includes: gamine, gcompris and tuxpaint</et>
   <eu>Pre-School. Includes: gamine, gcompris and tuxpaint</eu>
   <fa>Pre-School. Includes: gamine, gcompris and tuxpaint</fa>
   <fi>Pre-School. Includes: gamine, gcompris and tuxpaint</fi>
   <fr>Maternelle. Inclus: gamine, gcompris et tuxpaint</fr>
   <he_IL>Pre-School. Includes: gamine, gcompris and tuxpaint</he_IL>
   <hi>Pre-School. Includes: gamine, gcompris and tuxpaint</hi>
   <hr>Pre-School. Includes: gamine, gcompris and tuxpaint</hr>
   <hu>Pre-School. Includes: gamine, gcompris and tuxpaint</hu>
   <id>Pre-School. Includes: gamine, gcompris and tuxpaint</id>
   <is>Pre-School. Includes: gamine, gcompris and tuxpaint</is>
   <it>Elementari. Include: gamine, gcompris e tuxpaint</it>
   <ja_JP>Pre-School. Includes: gamine, gcompris and tuxpaint</ja_JP>
   <ja>Pre-School. Includes: gamine, gcompris and tuxpaint</ja>
   <kk>Pre-School. Includes: gamine, gcompris and tuxpaint</kk>
   <ko>Pre-School. Includes: gamine, gcompris and tuxpaint</ko>
   <lt>Pre-School. Includes: gamine, gcompris and tuxpaint</lt>
   <mk>Pre-School. Includes: gamine, gcompris and tuxpaint</mk>
   <nb>Pre-School. Includes: gamine, gcompris and tuxpaint</nb>
   <nl>Pre-School. Inclusief: gamine, gcompris en tuxpaint</nl>
   <pl>Przedszkole. Zawiera: gamine, gcompris i tuxpaint</pl>
   <pt_BR>Pré-escola/infantil. Inclui: gamine, gcompris e tuxpaint</pt_BR>
   <pt>Pré-escola/infantil. Inclui: gamine, gcompris e tuxpaint</pt>
   <ro>Pre-School. Includes: gamine, gcompris and tuxpaint</ro>
   <ru>Приложения для дошкольников: gamine, gcompris и tuxpaint</ru>
   <sk>Pre-School. Includes: gamine, gcompris and tuxpaint</sk>
   <sl>Pre-School. Includes: gamine, gcompris and tuxpaint</sl>
   <sq>Pre-School. Includes: gamine, gcompris and tuxpaint</sq>
   <sr>Pre-School. Includes: gamine, gcompris and tuxpaint</sr>
   <sv>Pre-School. Inkluderar: gamine, gcompris och tuxpaint</sv>
   <tr>Pre-School. Includes: gamine, gcompris and tuxpaint</tr>
   <uk>Pre-School. Includes: gamine, gcompris and tuxpaint</uk>
   <zh_CN>Pre-School. Includes: gamine, gcompris and tuxpaint</zh_CN>
   <zh_TW>Pre-School. Includes: gamine, gcompris and tuxpaint</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
gamine
gcompris
gcompris-sound-en
tuxpaint
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
gamine
gcompris
gcompris-sound-en
tuxpaint
</uninstall_package_names>
</app>
